import { LedgerChannelInfo, PaymentChannelInfo, PaymentPayload, ObjectiveResponse, Voucher, ReceiveVoucherResult, ChannelStatus, CounterChallengeAction, CounterChallengeResult, GetNodeInfo, AssetData, SwapAssetsData, SwapInitiatePayload, ConfirmSwapAction, ConfirmSwapResult, SwapChannelInfo } from "./types";
import { RpcClientApi } from "./interface";
export declare class NitroRpcClient implements RpcClientApi {
    private transport;
    private myAddress;
    private authToken;
    get Notifications(): import("eventemitter3").EventEmitter<"objective_completed" | "payment_channel_updated" | "ledger_channel_updated", {
        payload: string;
    } | {
        payload: PaymentChannelInfo;
    } | {
        payload: LedgerChannelInfo;
    }>;
    CreateVoucher(channelId: string, amount: number): Promise<Voucher>;
    ReceiveVoucher(voucher: Voucher): Promise<ReceiveVoucherResult>;
    WaitForObjectiveToComplete(objectiveId: string): Promise<void>;
    WaitForLedgerChannelStatus(channelId: string, status: ChannelStatus): Promise<void>;
    WaitForPaymentChannelStatus(channelId: string, status: ChannelStatus): Promise<void>;
    onPaymentChannelUpdated(channelId: string, callback: (info: PaymentChannelInfo) => void): () => void;
    CreateLedgerChannel(counterParty: string, assetsData: AssetData[], challengeDuration: number): Promise<ObjectiveResponse>;
    RetryObjectiveTx(objectiveId: string): Promise<string>;
    RetryTx(txHash: string): Promise<string>;
    CreateSwapChannel(counterParty: string, intermediaries: string[], assetsData: AssetData[]): Promise<ObjectiveResponse>;
    SwapAssets(channelId: string, swapAssetsData: SwapAssetsData): Promise<SwapInitiatePayload>;
    GetPendingSwap(channelId: string): Promise<string>;
    GetRecentSwaps(channelId: string): Promise<string>;
    CreatePaymentChannel(counterParty: string, intermediaries: string[], amount: number): Promise<ObjectiveResponse>;
    Pay(channelId: string, amount: number): Promise<PaymentPayload>;
    GetVoucher(channelId: string): Promise<Voucher>;
    CloseLedgerChannel(channelId: string, isChallenge: boolean): Promise<string>;
    CloseBridgeChannel(channelId: string): Promise<string>;
    MirrorBridgedDefund(channelId: string, stringifiedL2SignedState: string, isChallenge: boolean): Promise<string>;
    CounterChallenge(channelId: string, action: CounterChallengeAction, signedState?: string): Promise<CounterChallengeResult>;
    ConfirmSwap(swapId: string, action: ConfirmSwapAction): Promise<ConfirmSwapResult>;
    ClosePaymentChannel(channelId: string): Promise<string>;
    CloseSwapChannel(channelId: string): Promise<string>;
    GetVersion(): Promise<string>;
    GetNodeInfo(): Promise<GetNodeInfo>;
    GetAddress(): Promise<string>;
    GetLedgerChannel(channelId: string): Promise<LedgerChannelInfo>;
    GetAllLedgerChannels(): Promise<LedgerChannelInfo[]>;
    GetAllL2Channels(): Promise<LedgerChannelInfo[]>;
    GetSignedState(channelId: string): Promise<string>;
    GetPaymentChannel(channelId: string): Promise<PaymentChannelInfo>;
    GetSwapChannel(channelId: string): Promise<SwapChannelInfo>;
    GetPaymentChannelsByLedger(ledgerId: string): Promise<PaymentChannelInfo[]>;
    GetSwapChannelsByLedger(ledgerId: string): Promise<SwapChannelInfo[]>;
    GetObjective(objectiveId: string, l2: boolean): Promise<string>;
    GetL2ObjectiveFromL1(l1ObjectiveId: string): Promise<string>;
    GetPendingBridgeTxs(channelId: string): Promise<string>;
    private getAuthToken;
    private sendRequest;
    Close(): Promise<void>;
    private constructor();
    /**
     * Creates an RPC client that uses HTTP/WS as the transport.
     *
     * @param url - The URL of the HTTP/WS server
     * @returns A NitroRpcClient that uses WS as the transport
     */
    static CreateHttpNitroClient(url: string, isSecure: boolean): Promise<NitroRpcClient>;
}
