"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.unsecureHttpsAgent = exports.HttpTransport = void 0;
const https_1 = __importDefault(require("https"));
const axios_1 = __importDefault(require("axios"));
const websocket_1 = require("websocket");
const eventemitter3_1 = require("eventemitter3");
const serde_1 = require("../serde");
class HttpTransport {
    Notifications;
    isSecure;
    static async createTransport(server, isSecure) {
        let wsPrefix = "ws://";
        if (isSecure) {
            wsPrefix = "wss://";
        }
        // eslint-disable-next-line new-cap
        const ws = new websocket_1.w3cwebsocket(`${wsPrefix}${server}/subscribe`);
        // throw any websocket errors so we don't fail silently
        ws.onerror = (e) => {
            console.error("Error with websocket connection to server: " + e);
            throw e;
        };
        // Wait for onopen to fire so we know the connection is ready
        await new Promise((resolve) => (ws.onopen = () => resolve()));
        const transport = new HttpTransport(ws, server, isSecure);
        return transport;
    }
    async sendRequest(req) {
        let httpPrefix = "http://";
        if (this.isSecure) {
            httpPrefix = "https://";
        }
        const url = new URL(`${httpPrefix}${this.server}`).toString();
        const result = await axios_1.default.post(url.toString(), JSON.stringify(req));
        return result.data;
    }
    async Close() {
        this.ws.close(1000);
    }
    ws;
    server;
    constructor(ws, server, isSecure) {
        this.ws = ws;
        this.server = server;
        this.isSecure = isSecure;
        this.Notifications = new eventemitter3_1.EventEmitter();
        this.ws.onmessage = (event) => {
            const data = JSON.parse(event.data.toString());
            const validatedResult = (0, serde_1.getAndValidateNotification)(data.params.payload, data.method);
            this.Notifications.emit(data.method, validatedResult);
        };
    }
}
exports.HttpTransport = HttpTransport;
// For testing with self-signed certs, ignore certificate errors. DO NOT use in production.
function unsecureHttpsAgent() {
    // For testing with self-signed certs, ignore certificate errors. DO NOT use in production.
    const httpsAgent = new https_1.default.Agent({
        rejectUnauthorized: false,
    });
    return httpsAgent;
}
exports.unsecureHttpsAgent = unsecureHttpsAgent;
