"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.NatsTransport = void 0;
const nats_1 = require("nats");
const eventemitter3_1 = require("eventemitter3");
const NITRO_REQUEST_TOPIC = "nitro-request";
const NITRO_NOTIFICATION_TOPIC = "nitro-notify";
class NatsTransport {
    natsConn;
    natsSub;
    notifications = new eventemitter3_1.EventEmitter();
    static async createTransport(server) {
        const natConn = await (0, nats_1.connect)({ servers: server });
        const natsSub = natConn.subscribe(NITRO_NOTIFICATION_TOPIC);
        const transport = new NatsTransport(natConn, natsSub);
        // Start listening for messages without blocking
        transport.listenForMessages(transport.natsSub);
        return transport;
    }
    constructor(natsConn, natsSub) {
        this.natsConn = natsConn;
        this.natsSub = natsSub;
    }
    get Notifications() {
        return this.notifications;
    }
    async listenForMessages(sub) {
        for await (const msg of sub) {
            msg.data;
            const notif = (0, nats_1.JSONCodec)().decode(msg.data);
            switch (notif.method) {
                case "objective_completed":
                    this.notifications.emit(notif.method, notif);
                    break;
                case "ledger_channel_updated":
                    this.notifications.emit(notif.method, notif);
                    break;
                case "payment_channel_updated":
                    this.notifications.emit(notif.method, notif);
                    break;
            }
        }
    }
    async sendRequest(req) {
        const natsRes = await this.natsConn?.request(NITRO_REQUEST_TOPIC, (0, nats_1.JSONCodec)().encode(req));
        if (!natsRes) {
            throw new Error("No response");
        }
        const decoded = (0, nats_1.JSONCodec)().decode(natsRes?.data);
        return decoded;
    }
    async Close() {
        this.natsSub.unsubscribe();
        await this.natsConn.close();
    }
}
exports.NatsTransport = NatsTransport;
