import { NitroRpcClient } from "./rpc-client";
import { AssetData, Outcome, RequestMethod, RPCRequestAndResponses, SwapAssetsData } from "./types";
export declare const RPC_PATH = "api/v1";
/**
 * createOutcome creates a basic outcome for a channel
 *
 * @param asset - The asset to fund the channel with
 * @param alpha - The address of the first participant
 * @param beta - The address of the second participant
 * @param amount - The amount to allocate to each participant
 * @returns An outcome for a directly funded channel with 100 wei allocated to each participant
 */
export declare function createOutcome(alpha: string, beta: string, assetData: AssetData[]): Outcome;
/**
 * Left pads a 20 byte address hex string with zeros until it is a 32 byte hex string
 * e.g.,
 * 0x9546E319878D2ca7a21b481F873681DF344E0Df8 becomes
 * 0x0000000000000000000000009546E319878D2ca7a21b481F873681DF344E0Df8
 *
 * @param address - 20 byte hex string
 * @returns 32 byte padded hex string
 */
export declare function convertAddressToBytes32(address: string): string;
/**
 * generateRequest is a helper function that generates a request object for the given method and payloads
 *
 * @param method - The RPC method to generate a request for
 * @param payload - The payloads to include in the request
 * @returns A request object of the correct type
 */
export declare function generateRequest<K extends RequestMethod, T extends RPCRequestAndResponses[K][0]>(method: K, payload: T["params"]["payload"], authToken: string): T;
export declare function getLocalRPCUrl(port: number): string;
export declare function getRPCUrl(host: string, port: number): string;
export declare function logOutChannelUpdates(rpcClient: NitroRpcClient): Promise<void>;
export declare function prettyJson(obj: unknown): string;
export declare function compactJson(obj: unknown): string;
export declare function parseAssetData(assets: string[]): AssetData[];
export declare function parseSwapAssetsData(assetIn: string, assetOut: string): SwapAssetsData;
